@@ -7,9 +7,11 @@ function (x, digits = max(3, getOption("digits") - 3), ...)
     cat(formatC(x$statistic, digits = digits), "\n")
     nperm <- x$permutations
     if (nperm) {
-      cat("      Significance:",format.pval(x$signif, eps=1/nperm))
-      cat(" (based on ", nperm, " permutations)","\n")
+        cat("      Significance:", format.pval(x$signif, eps = 1/nperm),"\n\n")
+        cat("Based on ", nperm, " permutations")
     }
-    cat("\n")
+    if (!is.null(x$strata))
+        cat(", stratified within",x$strata)
+    cat("\n\n")
     invisible(x)
 }
